﻿Param(
[string]$Command,
[string]$BinaryPath,
[string]$ServiceName = "GdqStandardizeServer"
)

if (!$BinaryPath)
{
	$BinaryPath = join-path (get-location) "Experian.Gdq.Standardize.Standalone.exe"
}

function getStatus
{
    Get-WmiObject win32_service -Filter "name='$ServiceName'"
}

if ($Command)
{
	switch ($Command)
	{
		"install" 
		{ 
			if (-not (test-path $BinaryPath))
			{
				Write-Error "The specified executable cannot be found: $BinaryPath"
				Exit 1
			}
			New-Service -Name "$ServiceName" -BinaryPathName $BinaryPath -Description "GDQ Standardize Server" 
		}
		"uninstall" 
        { 
            Stop-Service "$ServiceName" -ErrorAction SilentlyContinue
            sc.exe delete "$ServiceName" 
        }
		"status" { break; }
		"start" { Start-Service "$ServiceName" }
		"stop" { Stop-Service "$ServiceName" }
		"restart" { Restart-Service "$ServiceName" }
		default { Write-Host "Invalid command ($Command)" }
	}
}

getStatus
